
===========
rchain-grpc
===========


.. image:: https://img.shields.io/pypi/v/rchain-grpc.svg
    :target: https://pypi.python.org/pypi/rchain-grpc

.. image:: https://travis-ci.com/proof-media/rchain-grpc.svg?branch=master
    :target: https://travis-ci.com/proof-media/rchain-grpc

.. image:: https://pyup.io/repos/github/proof-media/rchain-grpc/shield.svg
    :target: https://pyup.io/repos/github/proof-media/rchain-grpc/
    :alt: Updates



Python3 client for RChain nodes gRPC protocol


* Free software: MIT license
* Documentation: https://proof-media.github.io/rchain-grpc
